SMBC

Income Analysis (Consolidated)

## Overseas Operations

Notes: 1. Overseas operations comprise the operations of SMBC's overseas branches and its overseas consolidated subsidiaries.

- 2. In principle, average balances are calculated by using daily balances. However, some consolidated subsidiaries use weekly, monthly or quarterly balances instead.
- 3. "Interest-earning assets" are shown after deduction of the average balance of noninterest-earning deposits (2011, ¥103,430 million; 2010, ¥156,324 million).

## Total of Domestic and Overseas Operations

Notes: 1. The figures above comprise totals for domestic and overseas operations after intersegment eliminations.

- 2. In principle, average balances are calculated by using daily balances. However, some consolidated subsidiaries use weekly, monthly or quarterly balances instead.
- 3. "Interest-earning assets" are shown after deduction of the average balance of noninterest-earning deposits (2011, ¥1,239,571 million; 2010, ¥1,103,197 million).
- 4. Income and expenses resulting from money held in trust are included in "Other income" and "Other expenses." Therefore, "Interest-earning assets" are shown after deduction of the average balance of money held in trust (2011, ¥18,676 million; 2010, ¥12,392 million). "Interest-bearing liabilities" are shown after deduction of amounts equivalent to the average balance of money held in trust (2011, ¥18,676 million; 2010, ¥12,392 million) and corresponding interest (2011, ¥16 million; 2010, ¥20 million).

SMFG 2011 156